==> idris-1.3.0-60-armv7h.pkg.tar.xz: usr/share/haskell/register/idris.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: idris
version: 1.3.0
id: idris-1.3.0-ADOhdjjkL0cKNwbVoHMkkC
key: idris-1.3.0-ADOhdjjkL0cKNwbVoHMkkC
license: BSD-3-Clause
maintainer: Edwin Brady <eb@cs.st-andrews.ac.uk>
author: Edwin Brady
stability: Beta
homepage: http://www.idris-lang.org/
synopsis: Functional Programming Language with Dependent Types
description:
    Idris is a general purpose language with full dependent types.
    It is compiled, with eager evaluation.
    Dependent types allow types to be predicated on values,
    meaning that some aspects of a program'\''s behaviour can be
    specified precisely in the type. The language is closely
    related to Epigram and Agda. There is a tutorial at
    <http://www.idris-lang.org/documentation>.
    Features include:
    .
    * Full, first class, dependent types with dependent pattern matching
    .
    * where clauses, with rule, case expressions,
    pattern matching let and lambda bindings
    .
    * Interfaces (similar to type classes), monad comprehensions
    .
    * do notation, idiom brackets, syntactic conveniences for lists,
    tuples, dependent pairs
    .
    * Totality checking
    .
    * Coinductive types
    .
    * Indentation significant syntax, extensible syntax
    .
    * Cumulative universes
    .
    * Simple foreign function interface (to C)
    .
    * Hugs style interactive environment
category: Compilers/Interpreters, Dependent Types
abi: e2ac5d85dad7c876c2bb5d4e1700032d
exposed: True
exposed-modules:
    IRTS.Bytecode IRTS.CodegenC IRTS.CodegenCommon
    IRTS.CodegenJavaScript IRTS.Compiler IRTS.Defunctionalise
    IRTS.DumpBC IRTS.Exports IRTS.Inliner IRTS.JavaScript.AST
    IRTS.JavaScript.Codegen IRTS.JavaScript.LangTransforms
    IRTS.JavaScript.Name IRTS.JavaScript.PrimOp
    IRTS.JavaScript.Specialize IRTS.Lang IRTS.LangOpts IRTS.Portable
    IRTS.Simplified IRTS.System Idris.ASTUtils Idris.AbsSyntax
    Idris.AbsSyntaxTree Idris.Apropos Idris.CaseSplit Idris.Chaser
    Idris.CmdOptions Idris.Colours Idris.Completion Idris.Core.Binary
    Idris.Core.CaseTree Idris.Core.Constraints Idris.Core.DeepSeq
    Idris.Core.Elaborate Idris.Core.Evaluate Idris.Core.Execute
    Idris.Core.ProofState Idris.Core.ProofTerm Idris.Core.TT
    Idris.Core.Typecheck Idris.Core.Unify Idris.Core.WHNF
    Idris.Coverage Idris.DSL Idris.DataOpts Idris.DeepSeq
    Idris.Delaborate Idris.Directives Idris.Docs Idris.Docstrings
    Idris.Elab.AsPat Idris.Elab.Clause Idris.Elab.Data
    Idris.Elab.Implementation Idris.Elab.Interface Idris.Elab.Provider
    Idris.Elab.Quasiquote Idris.Elab.Record Idris.Elab.Rewrite
    Idris.Elab.RunElab Idris.Elab.Term Idris.Elab.Transform
    Idris.Elab.Type Idris.Elab.Utils Idris.Elab.Value Idris.ElabDecls
    Idris.Erasure Idris.ErrReverse Idris.Error Idris.Help Idris.IBC
    Idris.IdeMode Idris.IdrisDoc Idris.Imports Idris.Info
    Idris.Info.Show Idris.Inliner Idris.Interactive Idris.Main
    Idris.ModeCommon Idris.Options Idris.Output Idris.Package
    Idris.Package.Common Idris.Package.Parser Idris.Parser
    Idris.Parser.Data Idris.Parser.Expr Idris.Parser.Helpers
    Idris.Parser.Ops Idris.Parser.Stack Idris.PartialEval
    Idris.Primitives Idris.ProofSearch Idris.Prover Idris.Providers
    Idris.REPL Idris.REPL.Browse Idris.REPL.Commands Idris.REPL.Parser
    Idris.Reflection Idris.Termination Idris.Transforms
    Idris.TypeSearch Idris.Unlit Idris.WhoCalls Util.DynamicLinker
    Util.ScreenSize Util.System
hidden-modules: Util.Pretty Util.Net Paths_idris Version_idris
                Tools_idris BuildFlags_idris
import-dirs: /usr/lib/ghc-8.4.3/site-local/idris-1.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/idris-1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/idris
hs-libraries: HSidris-1.3.0-ADOhdjjkL0cKNwbVoHMkkC
extra-libraries:
    gmp
depends:
    base-4.11.1.0 aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL
    annotated-wl-pprint-0.7.0-5EJhaPPvnKODWMqVOHKqvI
    ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc
    ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4 array-0.5.2.0
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37 binary-0.8.5.1
    blaze-html-0.9.1.1-7NSQK15kZm4LYXM6mugOc0
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug bytestring-0.10.8.2
    cheapskate-0.1.1-D08GqKK84otGXXMcTwsF00
    code-page-0.1.3-78bf3rlibAi1l7KbTfbq3V containers-0.5.11.0
    deepseq-1.4.3.0 directory-1.3.1.5 filepath-1.4.2
    fingertree-0.1.4.1-AwW3TLkNv1xEwmTK7vREq4 haskeline-0.7.4.2
    ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46
    megaparsec-6.5.0-444ZVg94OsgBECw8zur7LD mtl-2.2.2
    network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu
    optparse-applicative-0.14.2.0-5kDvpaFLtQNB16vTZLs8dg pretty-1.1.3.6
    process-1.6.3.0 regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG
    terminal-size-0.3.2.1-KN6K6Ef1GMWIEqS2qb6D5y text-1.2.3.0
    time-1.8.0.2 transformers-0.5.5.0
    uniplate-1.6.12-7qe1vfYGuTJA8QWKhCYPuR
    unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    vector-binary-instances-0.2.4-DozAADK9jE3EJNfe3MCYFT
    zip-archive-0.3.3-BRFIWpxQDYCFgrwfEDUElx
    fsnotify-0.3.0.1-C2dayj02XCK5E2O4Q0iHp3
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe unix-2.7.2.2
    libffi-0.1-KciznLKKFMTLZ0dw70VJSt
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL=912860ab3519756596367ddae154025c
             annotated-wl-pprint-0.7.0-5EJhaPPvnKODWMqVOHKqvI=9b20128a6c9fe2f756d9a70be779da0b
             ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc=ac560d64fefa05d8067fac44b9aaa9de
             ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4=d46a34a69558ad25fb56e0bfd9741e31
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             blaze-html-0.9.1.1-7NSQK15kZm4LYXM6mugOc0=b90977d0094d15b5bd9e12114444ef75
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=71b515c6e3bfb99ff0075cc129b1fc3b
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cheapskate-0.1.1-D08GqKK84otGXXMcTwsF00=be3c73e6634d8effd62ebc2b60a69a11
             code-page-0.1.3-78bf3rlibAi1l7KbTfbq3V=ac79c284619ed805973e8a29b0490575
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             fingertree-0.1.4.1-AwW3TLkNv1xEwmTK7vREq4=d6a1fb3552b98ec4788d88dd477bef58
             haskeline-0.7.4.2=e6153d219f5fb7b64fb712b63f016a25
             ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46=9f6b114ae6eb47237e10ea290c9398cc
             megaparsec-6.5.0-444ZVg94OsgBECw8zur7LD=8b94ebb799b881d9cbb836d1782929fe
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu=43a70846fe67ebce9998ba267f800e6d
             optparse-applicative-0.14.2.0-5kDvpaFLtQNB16vTZLs8dg=ae7f0ef22284c6d85efc629be435c88e
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K=98feb6ae4c5e833326f77c1995f4743b
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG=cdf77c47c599317cfa01d2d98185c5d3
             terminal-size-0.3.2.1-KN6K6Ef1GMWIEqS2qb6D5y=e02b4a9f9e625ad33d6a73f3ba82bfb9
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             uniplate-1.6.12-7qe1vfYGuTJA8QWKhCYPuR=defe324fb2523260f738fbe6393c2beb
             unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa=81e1d2b217f05c2ba43642acf6d96f3b
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             vector-binary-instances-0.2.4-DozAADK9jE3EJNfe3MCYFT=a05eda2525e053256908ffd96812f0de
             zip-archive-0.3.3-BRFIWpxQDYCFgrwfEDUElx=400052d9ca926ad794e56ae7b67a3bbd
             fsnotify-0.3.0.1-C2dayj02XCK5E2O4Q0iHp3=f0e52d30d0907dbefad699c78b0c9db4
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
             libffi-0.1-KciznLKKFMTLZ0dw70VJSt=fcdb79951df3b23d7fe0b4923f7b2ffb
haddock-interfaces: /usr/share/doc/idris/html/idris.haddock
haddock-html: /usr/share/doc/idris/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> idris-1.3.0-64-armv7h.pkg.tar.xz: usr/share/haskell/register/idris.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: idris
version: 1.3.0
id: idris-1.3.0-7fBKLMk8p3u3ZIwkhFD5zo
key: idris-1.3.0-7fBKLMk8p3u3ZIwkhFD5zo
license: BSD-3-Clause
maintainer: Edwin Brady <eb@cs.st-andrews.ac.uk>
author: Edwin Brady
stability: Beta
homepage: http://www.idris-lang.org/
synopsis: Functional Programming Language with Dependent Types
description:
    Idris is a general purpose language with full dependent types.
    It is compiled, with eager evaluation.
    Dependent types allow types to be predicated on values,
    meaning that some aspects of a program'\''s behaviour can be
    specified precisely in the type. The language is closely
    related to Epigram and Agda. There is a tutorial at
    <http://www.idris-lang.org/documentation>.
    Features include:
    .
    * Full, first class, dependent types with dependent pattern matching
    .
    * where clauses, with rule, case expressions,
    pattern matching let and lambda bindings
    .
    * Interfaces (similar to type classes), monad comprehensions
    .
    * do notation, idiom brackets, syntactic conveniences for lists,
    tuples, dependent pairs
    .
    * Totality checking
    .
    * Coinductive types
    .
    * Indentation significant syntax, extensible syntax
    .
    * Cumulative universes
    .
    * Simple foreign function interface (to C)
    .
    * Hugs style interactive environment
category: Compilers/Interpreters, Dependent Types
abi: 90fdd04180125676f19e5ef0a5e09354
exposed: True
exposed-modules:
    IRTS.Bytecode IRTS.CodegenC IRTS.CodegenCommon
    IRTS.CodegenJavaScript IRTS.Compiler IRTS.Defunctionalise
    IRTS.DumpBC IRTS.Exports IRTS.Inliner IRTS.JavaScript.AST
    IRTS.JavaScript.Codegen IRTS.JavaScript.LangTransforms
    IRTS.JavaScript.Name IRTS.JavaScript.PrimOp
    IRTS.JavaScript.Specialize IRTS.Lang IRTS.LangOpts IRTS.Portable
    IRTS.Simplified IRTS.System Idris.ASTUtils Idris.AbsSyntax
    Idris.AbsSyntaxTree Idris.Apropos Idris.CaseSplit Idris.Chaser
    Idris.CmdOptions Idris.Colours Idris.Completion Idris.Core.Binary
    Idris.Core.CaseTree Idris.Core.Constraints Idris.Core.DeepSeq
    Idris.Core.Elaborate Idris.Core.Evaluate Idris.Core.Execute
    Idris.Core.ProofState Idris.Core.ProofTerm Idris.Core.TT
    Idris.Core.Typecheck Idris.Core.Unify Idris.Core.WHNF
    Idris.Coverage Idris.DSL Idris.DataOpts Idris.DeepSeq
    Idris.Delaborate Idris.Directives Idris.Docs Idris.Docstrings
    Idris.Elab.AsPat Idris.Elab.Clause Idris.Elab.Data
    Idris.Elab.Implementation Idris.Elab.Interface Idris.Elab.Provider
    Idris.Elab.Quasiquote Idris.Elab.Record Idris.Elab.Rewrite
    Idris.Elab.RunElab Idris.Elab.Term Idris.Elab.Transform
    Idris.Elab.Type Idris.Elab.Utils Idris.Elab.Value Idris.ElabDecls
    Idris.Erasure Idris.ErrReverse Idris.Error Idris.Help Idris.IBC
    Idris.IdeMode Idris.IdrisDoc Idris.Imports Idris.Info
    Idris.Info.Show Idris.Inliner Idris.Interactive Idris.Main
    Idris.ModeCommon Idris.Options Idris.Output Idris.Package
    Idris.Package.Common Idris.Package.Parser Idris.Parser
    Idris.Parser.Data Idris.Parser.Expr Idris.Parser.Helpers
    Idris.Parser.Ops Idris.Parser.Stack Idris.PartialEval
    Idris.Primitives Idris.ProofSearch Idris.Prover Idris.Providers
    Idris.REPL Idris.REPL.Browse Idris.REPL.Commands Idris.REPL.Parser
    Idris.Reflection Idris.Termination Idris.Transforms
    Idris.TypeSearch Idris.Unlit Idris.WhoCalls Util.DynamicLinker
    Util.ScreenSize Util.System
hidden-modules: Util.Pretty Util.Net Paths_idris Version_idris
                Tools_idris BuildFlags_idris
import-dirs: /usr/lib/ghc-8.4.3/site-local/idris-1.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/idris-1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/idris
hs-libraries: HSidris-1.3.0-7fBKLMk8p3u3ZIwkhFD5zo
extra-libraries:
    gmp
depends:
    base-4.11.1.0 aeson-1.4.1.0-GPUdiNXlyQm9pSbB9CFKk6
    annotated-wl-pprint-0.7.0-5EJhaPPvnKODWMqVOHKqvI
    ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc
    ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4 array-0.5.2.0
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37 binary-0.8.5.1
    blaze-html-0.9.1.1-crQaAXRkXt2XDlbzXFON9
    blaze-markup-0.8.2.2-DLsNA1WKDw36RR9ku6FlST bytestring-0.10.8.2
    cheapskate-0.1.1-1lwIUEETpthK362EKEQKwF
    code-page-0.1.3-78bf3rlibAi1l7KbTfbq3V containers-0.5.11.0
    deepseq-1.4.3.0 directory-1.3.1.5 filepath-1.4.2
    fingertree-0.1.4.1-AwW3TLkNv1xEwmTK7vREq4 haskeline-0.7.4.2
    ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46
    megaparsec-6.5.0-444ZVg94OsgBECw8zur7LD mtl-2.2.2
    network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu
    optparse-applicative-0.14.2.0-5kDvpaFLtQNB16vTZLs8dg pretty-1.1.3.6
    process-1.6.3.0 regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG
    terminal-size-0.3.2.1-KN6K6Ef1GMWIEqS2qb6D5y text-1.2.3.0
    time-1.8.0.2 transformers-0.5.5.0
    uniplate-1.6.12-CEZqf1ckZ8W1LfQ2yNgMUt
    unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    vector-binary-instances-0.2.4-DozAADK9jE3EJNfe3MCYFT
    zip-archive-0.3.3-BRFIWpxQDYCFgrwfEDUElx
    fsnotify-0.3.0.1-5nfcrBVG9cw2fvOUKCyDQS
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe unix-2.7.2.2
    libffi-0.1-KciznLKKFMTLZ0dw70VJSt
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             aeson-1.4.1.0-GPUdiNXlyQm9pSbB9CFKk6=22145541f26b56c63b48572ec79b9cbd
             annotated-wl-pprint-0.7.0-5EJhaPPvnKODWMqVOHKqvI=9b20128a6c9fe2f756d9a70be779da0b
             ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc=ac560d64fefa05d8067fac44b9aaa9de
             ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4=d46a34a69558ad25fb56e0bfd9741e31
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             blaze-html-0.9.1.1-crQaAXRkXt2XDlbzXFON9=c6e80aabf69818c42063522c698c33e8
             blaze-markup-0.8.2.2-DLsNA1WKDw36RR9ku6FlST=73c07c7dc173d95a5dd0d6c0058f8bb4
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cheapskate-0.1.1-1lwIUEETpthK362EKEQKwF=5a96ab9676f08d7ef44f8488691fa908
             code-page-0.1.3-78bf3rlibAi1l7KbTfbq3V=ac79c284619ed805973e8a29b0490575
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             fingertree-0.1.4.1-AwW3TLkNv1xEwmTK7vREq4=d6a1fb3552b98ec4788d88dd477bef58
             haskeline-0.7.4.2=e6153d219f5fb7b64fb712b63f016a25
             ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46=9f6b114ae6eb47237e10ea290c9398cc
             megaparsec-6.5.0-444ZVg94OsgBECw8zur7LD=8b94ebb799b881d9cbb836d1782929fe
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu=43a70846fe67ebce9998ba267f800e6d
             optparse-applicative-0.14.2.0-5kDvpaFLtQNB16vTZLs8dg=ae7f0ef22284c6d85efc629be435c88e
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K=98feb6ae4c5e833326f77c1995f4743b
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG=cdf77c47c599317cfa01d2d98185c5d3
             terminal-size-0.3.2.1-KN6K6Ef1GMWIEqS2qb6D5y=e02b4a9f9e625ad33d6a73f3ba82bfb9
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             uniplate-1.6.12-CEZqf1ckZ8W1LfQ2yNgMUt=2b370b8b93631b860e47002fa9510446
             unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre=264f905ec4c04eb05b5ff3d7321fae90
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             vector-binary-instances-0.2.4-DozAADK9jE3EJNfe3MCYFT=a05eda2525e053256908ffd96812f0de
             zip-archive-0.3.3-BRFIWpxQDYCFgrwfEDUElx=400052d9ca926ad794e56ae7b67a3bbd
             fsnotify-0.3.0.1-5nfcrBVG9cw2fvOUKCyDQS=d762812e67e47babbb5a05bfdf5997c0
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
             libffi-0.1-KciznLKKFMTLZ0dw70VJSt=fcdb79951df3b23d7fe0b4923f7b2ffb
haddock-interfaces: /usr/share/doc/idris/html/idris.haddock
haddock-html: /usr/share/doc/idris/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
